==> jmx4perl-0.36.tar.gz: jmx4perl-0.36/agent/modules/j4p-jar/src/main/java/org/jmx4perl/config/RestrictorFactory.java <==
package org.jmx4perl.config;

import java.io.InputStream;

/*
 * jmx4perl - WAR Agent for exporting JMX via JSON
 *
 * Copyright (C) 2009 Roland Huß, roland@cpan.org
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * A commercial license is available as well. Please contact roland@cpan.org for
 * further details.
 */

/**
 * Factory for obtaining the proper {@link org.jmx4perl.config.Restrictor}
 *
 * @author roland
 * @since Jul 28, 2009
 */
public final class RestrictorFactory {

    private RestrictorFactory() { }

    /**
     * Get the installed restrictor or the {@link org.jmx4perl.config.AllowAllRestrictor}
     * is no restrictions are in effect.
     *
     * @return the restrictor
     */
    public static Restrictor buildRestrictor() {

        InputStream is =
                Thread.currentThread().getContextClassLoader().getResourceAsStream("/j4p-access.xml");
        if (is != null) {
            return new PolicyBasedRestrictor(is);
        } else {
            return new AllowAllRestrictor();
        }
    }
}

==> jmx4perl-0.75.tar.gz: jmx4perl-0.75/agent/modules/j4p-jar/src/main/java/org/jmx4perl/config/RestrictorFactory.java <==
package org.jmx4perl.config;

import java.io.InputStream;

import org.jmx4perl.LogHandler;

/*
 * jmx4perl - WAR Agent for exporting JMX via JSON
 *
 * Copyright (C) 2009 Roland Huß, roland@cpan.org
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * A commercial license is available as well. Please contact roland@cpan.org for
 * further details.
 */

/**
 * Factory for obtaining the proper {@link org.jmx4perl.config.Restrictor}
 *
 * @author roland
 * @since Jul 28, 2009
 */
public final class RestrictorFactory {

    private RestrictorFactory() { }

    /**
     * Get the installed restrictor or the {@link org.jmx4perl.config.AllowAllRestrictor}
     * is no restrictions are in effect.
     *
     * @param pLogHandler log handler for printing out whether access restrictions are used or not
     * @return the restrictor
     */
    public static Restrictor buildRestrictor(LogHandler pLogHandler) {

        InputStream is =
                Thread.currentThread().getContextClassLoader().getResourceAsStream("/j4p-access.xml");
        if (is != null) {
            pLogHandler.info("j4p: Using security policy from 'j4p-access.xml'");
            return new PolicyBasedRestrictor(is);
        } else {
            pLogHandler.info("j4p: No security policy installed. Access to any MBean attribute and operation is permitted.");
            return new AllowAllRestrictor();
        }
    }
}
